package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.cryptopro.CryptoProObjectIdentifiers;
import cn.com.infosec.asn1.cryptopro.GOST3410PublicKeyAlgParameters;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.SubjectPublicKeyInfo;
import cn.com.infosec.crypto.params.GOST3410PublicKeyParameters;
import cn.com.infosec.jce.interfaces.GOST3410Params;
import cn.com.infosec.jce.interfaces.GOST3410PublicKey;
import cn.com.infosec.jce.spec.GOST3410ParameterSpec;
import cn.com.infosec.jce.spec.GOST3410PublicKeyParameterSetSpec;
import cn.com.infosec.jce.spec.GOST3410PublicKeySpec;
import java.io.IOException;
import java.math.BigInteger;

public class JDKGOST3410PublicKey implements GOST3410PublicKey {
   private BigInteger y;
   private GOST3410Params gost3410Spec;

   JDKGOST3410PublicKey(GOST3410PublicKeySpec spec) {
      JDKGOST3410PublicKey var10000 = this;
      super();
      this.y = spec.getY();
      GOST3410PublicKeySpec var10005 = spec;
      BigInteger var3 = spec.getP();
      BigInteger spec1 = spec.getQ();
      BigInteger var2 = var10005.getA();
      var10000.gost3410Spec = new GOST3410ParameterSpec(new GOST3410PublicKeyParameterSetSpec(var3, spec1, var2));
   }

   JDKGOST3410PublicKey(GOST3410PublicKey key) {
      this.y = key.getY();
      this.gost3410Spec = key.getParameters();
   }

   JDKGOST3410PublicKey(GOST3410PublicKeyParameters params, GOST3410ParameterSpec spec) {
      this.y = params.getY();
      this.gost3410Spec = spec;
   }

   JDKGOST3410PublicKey(BigInteger y, GOST3410ParameterSpec gost3410Spec) {
      this.y = y;
      this.gost3410Spec = gost3410Spec;
   }

   JDKGOST3410PublicKey(SubjectPublicKeyInfo info) {
      SubjectPublicKeyInfo var10000 = info;
      super();
      GOST3410PublicKeyAlgParameters var2;
      var2 = new GOST3410PublicKeyAlgParameters.<init>((ASN1Sequence)info.getAlgorithmId().getParameters());

      JDKGOST3410PublicKey var14;
      GOST3410PublicKeyAlgParameters var16;
      label65: {
         byte[] var12;
         boolean var10001;
         try {
            var12 = ((DEROctetString)var10000.getPublicKey()).getOctets();
         } catch (IOException var10) {
            var10001 = false;
            throw new IllegalArgumentException("invalid info structure in GOST3410 public key");
         }

         byte[] info1 = var12;

         try {
            var12 = new byte[var12.length];
         } catch (IOException var9) {
            var10001 = false;
            throw new IllegalArgumentException("invalid info structure in GOST3410 public key");
         }

         byte[] var3 = var12;
         int var4 = 0;

         while(true) {
            int var13;
            int var15;
            try {
               var13 = var4;
               var15 = info1.length;
            } catch (IOException var6) {
               var10001 = false;
               break;
            }

            if (var13 == var15) {
               try {
                  var14 = this;
                  var16 = var2;
                  this.y = new BigInteger(1, var3);
                  break label65;
               } catch (IOException var5) {
                  var10001 = false;
                  break;
               }
            }

            byte[] var10002;
            int var10003;
            try {
               var12 = var3;
               var15 = var4;
               var10002 = info1;
               var10003 = info1.length;
            } catch (IOException var8) {
               var10001 = false;
               break;
            }

            var10003 = var10003 - 1 - var4;

            try {
               var12[var15] = var10002[var10003];
            } catch (IOException var7) {
               var10001 = false;
               break;
            }

            ++var4;
         }

         throw new IllegalArgumentException("invalid info structure in GOST3410 public key");
      }

      var14.gost3410Spec = GOST3410ParameterSpec.fromPublicKeyAlg(var16);
   }

   public String getAlgorithm() {
      return "GOST3410";
   }

   public String getFormat() {
      return "X.509";
   }

   public byte[] getEncoded() {
      byte[] var1;
      byte[] var2;
      if ((var1 = this.getY().toByteArray())[0] == 0) {
         var2 = new byte[var1.length - 1];
      } else {
         var2 = new byte[var1.length];
      }

      for(int var3 = 0; var3 != var2.length; ++var3) {
         var2[var3] = var1[var1.length - 1 - var3];
      }

      GOST3410Params var5;
      SubjectPublicKeyInfo var6;
      SubjectPublicKeyInfo var10000;
      if ((var5 = this.gost3410Spec) instanceof GOST3410ParameterSpec) {
         if (var5.getEncryptionParamSetOID() != null) {
            var10000 = var6 = new SubjectPublicKeyInfo;
            DERObjectIdentifier var10003 = CryptoProObjectIdentifiers.gostR3410_94;
            DERObjectIdentifier var10006 = new DERObjectIdentifier(this.gost3410Spec.getPublicKeyParamSetOID());
            DERObjectIdentifier var10007 = new DERObjectIdentifier(this.gost3410Spec.getDigestParamSetOID());
            DERObjectIdentifier var7;
            var7 = new DERObjectIdentifier.<init>(this.gost3410Spec.getEncryptionParamSetOID());
            var10000.<init>(new AlgorithmIdentifier(var10003, (new GOST3410PublicKeyAlgParameters(var10006, var10007, var7)).getDERObject()), new DEROctetString(var2));
         } else {
            var6 = new SubjectPublicKeyInfo.<init>(new AlgorithmIdentifier(CryptoProObjectIdentifiers.gostR3410_94, (new GOST3410PublicKeyAlgParameters(new DERObjectIdentifier(this.gost3410Spec.getPublicKeyParamSetOID()), new DERObjectIdentifier(this.gost3410Spec.getDigestParamSetOID()))).getDERObject()), new DEROctetString(var2));
         }
      } else {
         var10000 = var6 = new SubjectPublicKeyInfo;
         AlgorithmIdentifier var10001 = new AlgorithmIdentifier(CryptoProObjectIdentifiers.gostR3410_94);
         DEROctetString var4;
         var4 = new DEROctetString.<init>(var2);
         var10000.<init>(var10001, var4);
      }

      return var6.getDEREncoded();
   }

   public GOST3410Params getParameters() {
      return this.gost3410Spec;
   }

   public BigInteger getY() {
      return this.y;
   }

   public String toString() {
      StringBuffer var10000 = new StringBuffer();
      String var1 = System.getProperty("line.separator");
      var10000.append("GOST3410 Public Key").append(var1);
      var10000.append("            y: ").append(this.getY().toString(16)).append(var1);
      return var10000.toString();
   }

   public boolean equals(Object o) {
      if (o instanceof JDKGOST3410PublicKey) {
         JDKGOST3410PublicKey o1 = (JDKGOST3410PublicKey)o;
         return this.y.equals(o1.y) && this.gost3410Spec.equals(o1.gost3410Spec);
      } else {
         return false;
      }
   }

   public int hashCode() {
      return this.y.hashCode() ^ this.gost3410Spec.hashCode();
   }
}
